### Name: FIGARO
### Title: Figures as R objects
### Aliases: FIGARO plot.default
### Keywords: hplot iplot aplot color internal

### ** Examples

# create a new figure object
p <- figaro(plot)
# plot some data
p$draw(runif(10), runif(10))
# change the main title
p$set(main="Figaro Demonstration")

# a histogram
h <- figaro(hist)
h$draw(rnorm(2000), col="blue")
# .. a better colour
h$set(col="yellow")

# using figaro with a style sheet
# create figure based on demo style from stylesheet 'fss'
d <- figaro(demo, fss="fss")
# draw a simple figure
d$draw(1:10)
# change the colour of the polygon 'pol1'
d$set("pol1", col="yellow")
# change the text
d$set("text", "Wow !", col='red', size=3. font=3)

# using figaro with a graphical object
# create some test data
x1 <- runif(10,0,10)
y1 <- runif(10,0,10)
x2 <- runif(10,5,15)
y2 <- runif(10,5,15)

# create two groups of point data
xy1 <- as.pgo(x1,y1,col="red", pch=16, label="Group A")
xy2 <- as.pgo(x2,y2, col="blue", pch=17, label="Group B")
# combine them
xy <- as.go(cpgo(xy1, xy2),xlab="X", ylab="Y")
# plot in the conventional way
plot(xy)
#plot in the figaro way
spot <- figaro(plot)
spot$draw(xy)
# change attributes of points
spot$set("points", col=c("khaki","green"))

# some more data
a <- 0:360*pi/180
ys <-sin(a*a)
yc <-cos(a)
y2 <- ys+yc+5
sw <- as.lgo(a,ys,col="green", label="Sine(a^2)")
cw <- as.lgo(a,yc, col="red", lty="dotted", label="Cos(a)")
yw <- as.lgo(a,y2,col="blue",label="Cos(a) + Sin(a^2)")
lp <- as.go(lines=clgo(sw,cw,yw),xlab="radians", ylab="amplitude")
#  draw using figaro
wave <- new(plot)
wave$draw(lp)
# .. and edit
wave$set(title="Adding Waveforms")

xylp <- cgo(xy, lp)
both <- new(plot)
both$draw(xylp)
both$set(title="Line and Point graphical object")
# add a legend,
#     select the location of the bottom left corner of the
#     legend box using the pointing device
both$legend()
both$set("lines", label=c("w1","w2", "w1 + w2"))



